#include <Imagine/Images.h>
#include "maxflow/graph.h"
#include <iostream>
#include <fstream>

using namespace std;
using namespace Imagine;

// This section shows how to use the library to compute a minimum cut on the following graph:
//
//		        SOURCE
//		       /       \
//		     1/         \6
//		     /      4    \
//		   node0 -----> node1
//		     |   <-----   |
//		     |      3     |
//		     \            /
//		     5\          /1
//		       \        /
//		          SINK
//
///////////////////////////////////////////////////

void testGCuts()
{
	Graph<int,int,int> g(/*estimated # of nodes*/ 2, /*estimated # of edges*/ 1); 
	g.add_node(2); 
	g.add_tweights( 0,   /* capacities */  1, 5 );
	g.add_tweights( 1,   /* capacities */  6, 1 );
	g.add_edge( 0, 1,    /* capacities */  4, 3 );
	int flow = g.maxflow();
	cout << "Flow = " << flow << endl;
	for (int i=0;i<2;i++)
		if (g.what_segment(i) == Graph<int,int,int>::SOURCE)
			cout << i << " is in the SOURCE set" << endl;
		else
			cout << i << " is in the SINK set" << endl;
}

void segment(string name,int zm,double alpha,double C1,double C2,double C3)
{
	Image<Color> I;
	load(I,stringSrcPath(name));
	int w=I.width(),h=I.height();
	Window W=openWindow(zm*w,zm*h);
	display(I);
	click();
	closeWindow(W);
	endGraphics();
}

int main() {
	testGCuts();
	segment("fishes.jpg",1,1.,1.,20.,.0002);
	return 0;
}
